@@ -6,8 +6,8 @@ acquisition for a Compax3 traverse controller.
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
-__date__ = "06-07-2020"
-__version__ = "0.0.6"
+__date__ = "23-07-2020"
+__version__ = "0.1.0"
 # pylint: disable=try-except-raise
 
 from PyQt5 import QtCore, QtGui
@@ -56,7 +56,6 @@ class Compax3_servo_qdev(QDeviceIO):
         DAQ_interval_ms=250,
         critical_not_alive_count=1,
         DAQ_timer_type=QtCore.Qt.CoarseTimer,
-        calc_DAQ_rate_every_N_iter=4,
         debug=False,
         **kwargs,
     ):
@@ -68,7 +67,6 @@ class Compax3_servo_qdev(QDeviceIO):
             DAQ_interval_ms=DAQ_interval_ms,
             DAQ_timer_type=DAQ_timer_type,
             critical_not_alive_count=critical_not_alive_count,
-            calc_DAQ_rate_every_N_iter=calc_DAQ_rate_every_N_iter,
             debug=debug,
         )
 
@@ -211,7 +209,7 @@ class Compax3_servo_qdev(QDeviceIO):
         """
         if self.dev.is_alive:
             # At startup
-            if self.DAQ_update_counter == 1:
+            if self.update_counter_DAQ == 1:
                 self.qled_new_pos.setText("%.2f" % self.dev.state.cur_pos)
 
             if self.dev.status_word_1.powerless:
@@ -245,7 +243,7 @@ class Compax3_servo_qdev(QDeviceIO):
             self.sw1_pos_reached.setChecked(self.dev.status_word_1.pos_reached)
             self.qled_cur_pos.setText("%.2f" % self.dev.state.cur_pos)
 
-            self.lbl_update_counter.setText("%s" % self.DAQ_update_counter)
+            self.lbl_update_counter.setText("%s" % self.update_counter_DAQ)
         else:
             self.qgrp.setEnabled(False)
 
