@@ -10,8 +10,8 @@ refer to this device as a multiplexer, or mux.
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
-__date__ = "07-07-2020"
-__version__ = "0.0.6"
+__date__ = "23-07-2020"
+__version__ = "0.1.0"
 # pylint: disable=broad-except
 
 from PyQt5 import QtCore, QtGui
@@ -106,7 +106,6 @@ class Keysight_3497xA_qdev(QDeviceIO):
         DAQ_interval_ms=1000,
         DAQ_timer_type=QtCore.Qt.CoarseTimer,
         critical_not_alive_count=3,
-        calc_DAQ_rate_every_N_iter=1,
         DAQ_postprocess_MUX_scan_function=None,
         debug=False,
         **kwargs,
@@ -119,7 +118,6 @@ class Keysight_3497xA_qdev(QDeviceIO):
             DAQ_interval_ms=DAQ_interval_ms,
             DAQ_timer_type=DAQ_timer_type,
             critical_not_alive_count=critical_not_alive_count,
-            calc_DAQ_rate_every_N_iter=calc_DAQ_rate_every_N_iter,
             debug=debug,
         )
 
@@ -374,7 +372,7 @@ class Keysight_3497xA_qdev(QDeviceIO):
             self.qled_obtained_interval_ms.setText(
                 "%.0f" % self.obtained_DAQ_interval_ms
             )
-            self.qlbl_update_counter.setText("%s" % self.DAQ_update_counter)
+            self.qlbl_update_counter.setText("%s" % self.update_counter_DAQ)
 
             for i in range(len(self.dev.state.all_scan_list_channels)):
                 if i >= len(self.dev.state.readings):
@@ -474,9 +472,9 @@ class Keysight_3497xA_qdev(QDeviceIO):
         if reply == QtWid.QMessageBox.Yes:
             self.qpbt_start_scan.setChecked(False)
             self.stop_MUX_scan()
-            self.add_to_send_queue(self.dev.wait_for_OPC)
-            self.add_to_send_queue(self.dev.begin)
-            self.process_send_queue()
+            self.add_to_jobs_queue(self.dev.wait_for_OPC)
+            self.add_to_jobs_queue(self.dev.begin)
+            self.process_jobs_queue()
 
     @QtCore.pyqtSlot()
     def process_qpbt_debug_test(self):
