@@ -3,10 +3,12 @@
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
-__date__ = "15-07-2020"  # 0.0.1 was stamped 18-09-2018
-__version__ = "0.0.6"  # 0.0.1 corresponds to prototype 1.0.0
+__date__ = "15-07-2020"
+__version__ = "0.1.0"
 # pylint: disable=bare-except
 
+# Note: The `connection_lost` mechanism is not implemented on purpose
+
 import os
 import sys
 from pathlib import Path
