@@ -6,8 +6,8 @@ acquisition for a Keysight N8700 power supply (PSU).
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
-__date__ = "07-07-2020"
-__version__ = "0.0.6"
+__date__ = "23-07-2020"
+__version__ = "0.1.0"
 
 import numpy as np
 
@@ -75,7 +75,6 @@ class Keysight_N8700_qdev(QDeviceIO):
         DAQ_interval_ms=200,
         DAQ_timer_type=QtCore.Qt.CoarseTimer,
         critical_not_alive_count=1,
-        calc_DAQ_rate_every_N_iter=5,
         debug=False,
         **kwargs,
     ):
@@ -91,7 +90,6 @@ class Keysight_N8700_qdev(QDeviceIO):
             DAQ_interval_ms=DAQ_interval_ms,
             DAQ_timer_type=DAQ_timer_type,
             critical_not_alive_count=critical_not_alive_count,
-            calc_DAQ_rate_every_N_iter=calc_DAQ_rate_every_N_iter,
             debug=debug,
         )
 
@@ -426,7 +424,7 @@ class Keysight_N8700_qdev(QDeviceIO):
             self.errors.setReadOnly(self.dev.state.all_errors != [])
             self.errors.setText("%s" % ";".join(self.dev.state.all_errors))
 
-            self.lbl_update_counter.setText("%s" % self.DAQ_update_counter)
+            self.lbl_update_counter.setText("%s" % self.update_counter_DAQ)
         else:
             self.V_meas.setText("")
             self.I_meas.setText("Offline")
@@ -504,11 +502,11 @@ class Keysight_N8700_qdev(QDeviceIO):
 
         if reply == QtWid.QMessageBox.Yes:
             self.dev.read_config_file()
-            self.add_to_send_queue(self.dev.reinitialize)
-            self.add_to_send_queue(
+            self.add_to_jobs_queue(self.dev.reinitialize)
+            self.add_to_jobs_queue(
                 "signal_GUI_input_field_update", GUI_input_fields.ALL
             )
-            self.process_send_queue()
+            self.process_jobs_queue()
 
             self.dev.state.ENA_PID = False
 
@@ -560,12 +558,12 @@ class Keysight_N8700_qdev(QDeviceIO):
         if voltage < 0:
             voltage = 0
 
-        self.add_to_send_queue(self.dev.set_V_source, voltage)
-        self.add_to_send_queue(self.dev.query_V_source)
-        self.add_to_send_queue(
+        self.add_to_jobs_queue(self.dev.set_V_source, voltage)
+        self.add_to_jobs_queue(self.dev.query_V_source)
+        self.add_to_jobs_queue(
             "signal_GUI_input_field_update", GUI_input_fields.V_source
         )
-        self.process_send_queue()
+        self.process_jobs_queue()
 
     def send_I_source_from_textbox(self):
         try:
@@ -578,12 +576,12 @@ class Keysight_N8700_qdev(QDeviceIO):
         if current < 0:
             current = 0
 
-        self.add_to_send_queue(self.dev.set_I_source, current)
-        self.add_to_send_queue(self.dev.query_I_source)
-        self.add_to_send_queue(
+        self.add_to_jobs_queue(self.dev.set_I_source, current)
+        self.add_to_jobs_queue(self.dev.query_I_source)
+        self.add_to_jobs_queue(
             "signal_GUI_input_field_update", GUI_input_fields.I_source
         )
-        self.process_send_queue()
+        self.process_jobs_queue()
 
     def set_P_source_from_textbox(self):
         try:
@@ -606,12 +604,12 @@ class Keysight_N8700_qdev(QDeviceIO):
         except:
             raise
 
-        self.add_to_send_queue(self.dev.set_OVP_level, OVP_level)
-        self.add_to_send_queue(self.dev.query_OVP_level)
-        self.add_to_send_queue(
+        self.add_to_jobs_queue(self.dev.set_OVP_level, OVP_level)
+        self.add_to_jobs_queue(self.dev.query_OVP_level)
+        self.add_to_jobs_queue(
             "signal_GUI_input_field_update", GUI_input_fields.OVP_level
         )
-        self.process_send_queue()
+        self.process_jobs_queue()
 
     # --------------------------------------------------------------------------
     #   connect_signals_to_slots
