@@ -6,8 +6,8 @@ acquisition for a Picotech PT-104 pt100/1000 temperature logger.
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
-__date__ = "07-07-2020"
-__version__ = "0.0.6"
+__date__ = "23-07-2020"
+__version__ = "0.1.0"
 
 import numpy as np
 
@@ -64,7 +64,6 @@ class Picotech_PT104_qdev(QDeviceIO):
         DAQ_interval_ms=1000,
         DAQ_timer_type=QtCore.Qt.CoarseTimer,
         critical_not_alive_count=np.nan,
-        calc_DAQ_rate_every_N_iter=1,
         debug=False,
         **kwargs,
     ):
@@ -76,7 +75,6 @@ class Picotech_PT104_qdev(QDeviceIO):
             DAQ_interval_ms=DAQ_interval_ms,
             DAQ_timer_type=DAQ_timer_type,
             critical_not_alive_count=critical_not_alive_count,
-            calc_DAQ_rate_every_N_iter=calc_DAQ_rate_every_N_iter,
             debug=debug,
         )
 
@@ -151,7 +149,7 @@ class Picotech_PT104_qdev(QDeviceIO):
             self.qled_T_ch2.setText("%.3f" % self.dev.state.ch2_T)
             self.qled_T_ch3.setText("%.3f" % self.dev.state.ch3_T)
             self.qled_T_ch4.setText("%.3f" % self.dev.state.ch4_T)
-            self.qlbl_update_counter.setText("%s" % self.DAQ_update_counter)
+            self.qlbl_update_counter.setText("%s" % self.update_counter_DAQ)
         else:
             self.qgrp.setEnabled(False)
             self.qlbl_offline.setVisible(True)
