@@ -10,7 +10,7 @@ __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
 __date__ = "15-07-2020"
-__version__ = "0.0.6"
+__version__ = "0.1.0"
 # pylint: disable=try-except-raise, bare-except
 
 import sys
@@ -36,7 +36,7 @@ class PolyScience_PD_bath(SerialDevice):
         super().__init__(name=name, long_name=long_name)
 
         # Default serial settings
-        self.serial_init_kwargs = {
+        self.serial_settings = {
             "baudrate": 57600,
             "timeout": 0.5,
             "write_timeout": 0.5,
