@@ -16,7 +16,7 @@ __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
 __date__ = "15-07-2020"
-__version__ = "0.0.6"
+__version__ = "0.1.0"
 # pylint: disable=bare-except, broad-except, try-except-raise
 
 import sys
@@ -137,7 +137,7 @@ class ThermoFlex_chiller(SerialDevice):
         super().__init__(name=name, long_name=long_name)
 
         # Default serial settings
-        self.serial_init_kwargs = {
+        self.serial_settings = {
             "baudrate": 9600,
             "timeout": 1,
             "write_timeout": 1,
