@@ -6,8 +6,8 @@ acquisition for a Thermo Scientific ThermoFlex recirculating chiller.
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
-__date__ = "07-07-2020"
-__version__ = "0.0.6"
+__date__ = "23-07-2020"
+__version__ = "0.1.0"
 
 from PyQt5 import QtCore, QtGui
 from PyQt5 import QtWidgets as QtWid
@@ -60,7 +60,6 @@ class ThermoFlex_chiller_qdev(QDeviceIO):
         DAQ_interval_ms=1000,
         DAQ_timer_type=QtCore.Qt.CoarseTimer,
         critical_not_alive_count=1,
-        calc_DAQ_rate_every_N_iter=1,
         debug=False,
         **kwargs,
     ):
@@ -72,7 +71,6 @@ class ThermoFlex_chiller_qdev(QDeviceIO):
             DAQ_interval_ms=DAQ_interval_ms,
             DAQ_timer_type=DAQ_timer_type,
             critical_not_alive_count=critical_not_alive_count,
-            calc_DAQ_rate_every_N_iter=calc_DAQ_rate_every_N_iter,
             debug=debug,
         )
 
@@ -383,7 +381,7 @@ class ThermoFlex_chiller_qdev(QDeviceIO):
         """
         if self.dev.is_alive:
             # At startup
-            if self.DAQ_update_counter == 1:
+            if self.update_counter_DAQ == 1:
                 self.update_GUI_alarm_values()
                 self.update_GUI_PID_values()
                 self.send_setpoint.setText("%.1f" % self.dev.state.setpoint)
@@ -440,7 +438,7 @@ class ThermoFlex_chiller_qdev(QDeviceIO):
             self.SB_phase_monitor.setChecked(SBs.phase_monitor_fault)
             self.SB_sense_5V.setChecked(SBs.sense_5V_fault)
 
-            self.lbl_update_counter.setText("%s" % self.DAQ_update_counter)
+            self.lbl_update_counter.setText("%s" % self.update_counter_DAQ)
         else:
             self.grpb_alarms.setEnabled(False)
             self.grpb_PID.setEnabled(False)
@@ -481,15 +479,15 @@ class ThermoFlex_chiller_qdev(QDeviceIO):
 
     @QtCore.pyqtSlot()
     def process_pbtn_read_alarm_values(self):
-        self.add_to_send_queue(self.dev.query_alarm_values_and_units)
-        self.add_to_send_queue("signal_GUI_alarm_values_update")
-        self.process_send_queue()
+        self.add_to_jobs_queue(self.dev.query_alarm_values_and_units)
+        self.add_to_jobs_queue("signal_GUI_alarm_values_update")
+        self.process_jobs_queue()
 
     @QtCore.pyqtSlot()
     def process_pbtn_read_PID_values(self):
-        self.add_to_send_queue(self.dev.query_PID_values)
-        self.add_to_send_queue("signal_GUI_PID_values_update")
-        self.process_send_queue()
+        self.add_to_jobs_queue(self.dev.query_PID_values)
+        self.add_to_jobs_queue("signal_GUI_PID_values_update")
+        self.process_jobs_queue()
 
     @QtCore.pyqtSlot()
     def send_setpoint_from_textbox(self):
